@@ -179,6 +179,71 @@ def test_backend_methods(backend):
     )
 
 
+@pytest.mark.parametrize("backend", [lf("npb"), lf("tfb"), lf("jaxb"), lf("torchb")])
+def test_backend_methods_2(backend):
+    np.testing.assert_allclose(tc.backend.mean(tc.backend.ones([10])), 1.0, atol=1e-5)
+    # acos acosh asin asinh atan atan2 atanh cosh (cos) tan tanh sinh (sin)
+    np.testing.assert_allclose(
+        tc.backend.acos(tc.backend.ones([2], dtype="float32")),
+        np.arccos(tc.backend.ones([2])),
+        atol=1e-5,
+    )
+    np.testing.assert_allclose(
+        tc.backend.acosh(tc.backend.ones([2], dtype="float32")),
+        np.arccosh(tc.backend.ones([2])),
+        atol=1e-5,
+    )
+    np.testing.assert_allclose(
+        tc.backend.asin(tc.backend.ones([2], dtype="float32")),
+        np.arcsin(tc.backend.ones([2])),
+        atol=1e-5,
+    )
+    np.testing.assert_allclose(
+        tc.backend.asinh(tc.backend.ones([2], dtype="float32")),
+        np.arcsinh(tc.backend.ones([2])),
+        atol=1e-5,
+    )
+    np.testing.assert_allclose(
+        tc.backend.atan(0.5 * tc.backend.ones([2], dtype="float32")),
+        np.arctan(0.5 * tc.backend.ones([2])),
+        atol=1e-5,
+    )
+    np.testing.assert_allclose(
+        tc.backend.atan2(
+            tc.backend.ones([1], dtype="float32"), tc.backend.ones([1], dtype="float32")
+        ),
+        np.arctan2(
+            tc.backend.ones([1], dtype="float32"), tc.backend.ones([1], dtype="float32")
+        ),
+        atol=1e-5,
+    )
+    np.testing.assert_allclose(
+        tc.backend.atanh(0.5 * tc.backend.ones([2], dtype="float32")),
+        np.arctanh(0.5 * tc.backend.ones([2])),
+        atol=1e-5,
+    )
+    np.testing.assert_allclose(
+        tc.backend.cosh(tc.backend.ones([2], dtype="float32")),
+        np.cosh(tc.backend.ones([2])),
+        atol=1e-5,
+    )
+    np.testing.assert_allclose(
+        tc.backend.tan(tc.backend.ones([2], dtype="float32")),
+        np.tan(tc.backend.ones([2])),
+        atol=1e-5,
+    )
+    np.testing.assert_allclose(
+        tc.backend.tanh(tc.backend.ones([2], dtype="float32")),
+        np.tanh(tc.backend.ones([2])),
+        atol=1e-5,
+    )
+    np.testing.assert_allclose(
+        tc.backend.sinh(0.5 * tc.backend.ones([2], dtype="float32")),
+        np.sinh(0.5 * tc.backend.ones([2])),
+        atol=1e-5,
+    )
+
+
 @pytest.mark.parametrize("backend", [lf("npb"), lf("tfb"), lf("jaxb"), lf("torchb")])
 def test_arg_cmp(backend):
     np.testing.assert_allclose(tc.backend.argmax(tc.backend.ones([3], "float64")), 0)
@@ -279,18 +344,18 @@ def vqe_energy(inputs, param, n, nlayers):
 def test_vvag(backend):
     n = 4
     nlayers = 3
-    inp = tc.backend.ones([2 ** n]) / 2 ** (n / 2)
+    inp = tc.backend.ones([2**n]) / 2 ** (n / 2)
     param = tc.backend.ones([2 * nlayers, n])
     inp = tc.backend.cast(inp, "complex64")
     param = tc.backend.cast(param, "complex64")
 
     vqe_energy_p = partial(vqe_energy, n=n, nlayers=nlayers)
 
-    vag = tc.backend.value_and_grad(vqe_energy_p, argnums=(0, 1))
-    v0, (g00, g01) = vag(inp, param)
+    vg = tc.backend.value_and_grad(vqe_energy_p, argnums=(0, 1))
+    v0, (g00, g01) = vg(inp, param)
 
     batch = 8
-    inps = tc.backend.ones([batch, 2 ** n]) / 2 ** (n / 2)
+    inps = tc.backend.ones([batch, 2**n]) / 2 ** (n / 2)
     inps = tc.backend.cast(inps, "complex64")
 
     pvag = tc.backend.vvag(vqe_energy_p, argnums=(0, 1))
@@ -317,7 +382,7 @@ def test_vvag_dict(backend):
 @pytest.mark.parametrize("backend", [lf("tfb"), lf("jaxb"), lf("torchb")])
 def test_vjp(backend):
     def f(x):
-        return x ** 2
+        return x**2
 
     inputs = tc.backend.ones([2, 2])
     v, g = tc.backend.vjp(f, inputs, inputs)
@@ -345,7 +410,7 @@ def test_vjp_complex(backend):
     np.testing.assert_allclose(tc.backend.numpy(g), np.ones([1]), atol=1e-5)
 
     def f2(x):
-        return x ** 2
+        return x**2
 
     inputs = tc.backend.ones([1]) + 1.0j * tc.backend.ones([1])
     v = tc.backend.ones([1], dtype="complex64")  # + 1.0j * tc.backend.ones([1])
@@ -375,7 +440,7 @@ def test_vjp_pytree(backend):
 @pytest.mark.parametrize("backend", [lf("tfb"), lf("jaxb"), lf("torchb")])
 def test_jvp(backend):
     def f(x):
-        return x ** 2
+        return x**2
 
     inputs = tc.backend.ones([2, 2])
     v, g = tc.backend.jvp(f, inputs, inputs)
@@ -404,7 +469,7 @@ def test_jvp_complex(backend):
     np.testing.assert_allclose(tc.backend.numpy(g), np.ones([1]), atol=1e-5)
 
     def f2(x):
-        return x ** 2
+        return x**2
 
     inputs = tc.backend.ones([1]) + 1.0j * tc.backend.ones([1])
     v = tc.backend.ones([1]) + 1.0j * tc.backend.ones([1])
@@ -431,27 +496,27 @@ def test_jac(backend, mode):
     backend_jac = getattr(tc.backend, mode)
 
     def f(x):
-        return x ** 2
+        return x**2
 
     x = tc.backend.ones([3])
     jacf = backend_jac(f)
     np.testing.assert_allclose(jacf(x), 2 * np.eye(3), atol=1e-5)
 
     def f2(x):
-        return x ** 2, x
+        return x**2, x
 
     jacf2 = backend_jac(f2)
     np.testing.assert_allclose(jacf2(x)[1], np.eye(3), atol=1e-5)
     np.testing.assert_allclose(jacf2(x)[0], 2 * np.eye(3), atol=1e-5)
 
     def f3(x, y):
-        return x + y ** 2
+        return x + y**2
 
     jacf3 = backend_jac(f3, argnums=(0, 1))
     np.testing.assert_allclose(jacf3(x, x)[1], 2 * np.eye(3), atol=1e-5)
 
     def f4(x, y):
-        return x ** 2, y
+        return x**2, y
 
     # note the subtle difference of two tuples order in jacrev and jacfwd for current API
     # the value happen to be the same here, though
@@ -466,7 +531,7 @@ def test_jac_md_input(backend, mode):
     backend_jac = getattr(tc.backend, mode)
 
     def f(x):
-        return x ** 2
+        return x**2
 
     x = tc.backend.ones([2, 3])
     jacf = backend_jac(f)
@@ -500,7 +565,7 @@ def test_jac_tall(backend, mode):
 def test_vvag_has_aux(backend):
     def f(x):
         y = tc.backend.sum(x)
-        return tc.backend.real(y ** 2), y
+        return tc.backend.real(y**2), y
 
     fvvag = tc.backend.vvag(f, has_aux=True)
     (_, v1), _ = fvvag(tc.backend.ones([10, 2]))
@@ -676,16 +741,16 @@ def test_with_level_set_return(backend):
 @pytest.mark.parametrize("backend", [lf("tfb"), lf("jaxb"), lf("torchb")])
 def test_grad_has_aux(backend):
     def f(x):
-        return tc.backend.real(x ** 2), x ** 3
+        return tc.backend.real(x**2), x**3
 
-    vag = tc.backend.value_and_grad(f, has_aux=True)
+    vg = tc.backend.value_and_grad(f, has_aux=True)
 
     np.testing.assert_allclose(
-        vag(tc.backend.ones([]))[1], 2 * tc.backend.ones([]), atol=1e-5
+        vg(tc.backend.ones([]))[1], 2 * tc.backend.ones([]), atol=1e-5
     )
 
     def f2(x):
-        return tc.backend.real(x ** 2), (x ** 3, tc.backend.ones([3]))
+        return tc.backend.real(x**2), (x**3, tc.backend.ones([3]))
 
     gs = tc.backend.grad(f2, has_aux=True)
     np.testing.assert_allclose(gs(tc.backend.ones([]))[0], 2.0, atol=1e-5)
@@ -717,7 +782,7 @@ def test_optimizers(backend):
         c = tc.templates.blocks.example_block(c, params["b"])
         return tc.backend.real(c.expectation([tc.gates.x(), [n // 2]]))
 
-    vags = tc.backend.jit(tc.backend.value_and_grad(f, argnums=0), static_argnums=1)
+    vgs = tc.backend.jit(tc.backend.value_and_grad(f, argnums=0), static_argnums=1)
 
     def get_opt():
         if tc.backend.name == "tensorflow":
@@ -739,7 +804,7 @@ def test_optimizers(backend):
     }
 
     for _ in range(20):
-        loss, grads = vags(params, n)
+        loss, grads = vgs(params, n)
         params = opt.update(grads, params)
         print(loss)
 
@@ -750,13 +815,13 @@ def test_optimizers(backend):
         c = tc.templates.blocks.example_block(c, params)
         return tc.backend.real(c.expectation([tc.gates.x(), [n // 2]]))
 
-    vags2 = tc.backend.jit(tc.backend.value_and_grad(f2, argnums=0), static_argnums=1)
+    vgs2 = tc.backend.jit(tc.backend.value_and_grad(f2, argnums=0), static_argnums=1)
 
     params = tc.backend.implicit_randn([4, n])
     opt = get_opt()
 
     for _ in range(20):
-        loss, grads = vags2(params, n)
+        loss, grads = vgs2(params, n)
         print(grads, params)
         params = opt.update(grads, params)
         print(loss)
@@ -768,7 +833,7 @@ def test_optimizers(backend):
 def test_hessian(backend):
     # hessian support is now very fragile and especially has potential issues on tf backend
     def f(param):
-        return tc.backend.sum(param ** 2)
+        return tc.backend.sum(param**2)
 
     hf = tc.backend.hessian(f)
     param = tc.backend.ones([2])
